# GiQuant

This Python package contain various tools for Quantative Finance and Trading.
It should be considered an alpha version but feel free to try it out!

Install from PyPi with: `python3 -m pip install giquant`


## TimeSeriesLanguage

`giquiant.tsl` is a DSL (domain specific language) for manipulation of time series.

Show the help with: `python3 -m giquant.tsl.expr --help`


## Trading

The trade subpackage has some tools related to trading.

Show the help with:

* `python3 -m giquant.trade.dwnl --help`
* `python3 -m giquant.trade.cl --help`
* `python3 -m giquant.trade.cc --help`
